# -*- coding: utf-8 -*-
# Generated by Django 1.11.25 on 2019-10-03 11:45
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0003_auto_20191002_1425'),
    ]

    operations = [
        migrations.AddField(
            model_name='member',
            name='is_captain',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='project',
            name='team',
            field=models.ManyToManyField(through='djangoldp_project.Member', to=settings.AUTH_USER_MODEL),
        ),
    ]
