# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-10-02 14:25
from __future__ import unicode_literals

from django.db import migrations, models
import djangoldp_project.models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0002_auto_20190917_1122'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='number',
            field=models.PositiveIntegerField(default=djangoldp_project.models.auto_increment_project_number, editable=False),
        ),
    ]
